@@ -754,7 +754,16 @@ get_compiler_id (const char *compiler)
 #endif
 
 #ifdef G_OS_WIN32
-      if (g_getenv ("MSYSTEM") != NULL)
+      /* For Visual Studio builds: if a developer shell is detected,
+         immediately assume MSVC so we don't DoS the user with octal
+         strings.
+         See https://developercommunity.visualstudio.com/t/Long-octal-formatted-strings-DoS-the-use/11021201
+       */
+      if (g_getenv ("VCINSTALLDIR") != NULL)
+        {
+          compiler = "msvc"; 
+        }
+      else if (g_getenv ("MSYSTEM") != NULL)
         {
           const char *compiler_env = g_getenv ("CC");
 
@@ -1070,10 +1079,11 @@ main (int argc, char **argv)
     {
       if (generate_source)
 	{
-	  int fd = g_file_open_tmp (NULL, &binary_target, NULL);
+	  int fd = g_file_open_tmp (NULL, &binary_target, &error);
 	  if (fd == -1)
 	    {
-	      g_printerr ("Can't open temp file\n");
+	      g_printerr ("Can't open temp file: %s\n", error->message);
+              g_error_free (error);
 	      g_free (c_name);
               g_hash_table_unref (files);
 	      return 1;
